@@ -73,11 +73,16 @@ module Data.SafeCopy
     (
       safeGet
     , safePut
-    , SafeCopy(version, kind, getCopy, putCopy, errorTypeName)
+    , SafeCopy(version, kind, getCopy, putCopy, objectProfile, errorTypeName)
+    , Profile(..)
     , Prim(..)
     , Migrate(..)
+    , Reverse(..)
     , Kind
     , extension
+    , extended_extension
+    , extended_base
+    , base
     , Contained
     , contain
     , Version
@@ -94,7 +99,6 @@ module Data.SafeCopy
     , getSafeGet
     , getSafePut
     , primitive
-    , base
     ) where
 
 import Data.SafeCopy.Instances ()
