@@ -1,4 +1,4 @@
-{-# LANGUAGE FlexibleContexts, UndecidableInstances #-}
+{-# LANGUAGE FlexibleContexts, UndecidableInstances, CPP #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 module Data.SafeCopy.Instances where
 
@@ -31,7 +31,11 @@ import           Data.Time.Clock (DiffTime, NominalDiffTime, UniversalTime(..),
 import           Data.Time.Clock.TAI (AbsoluteTime, taiEpoch, addAbsoluteTime, diffAbsoluteTime)
 import           Data.Time.LocalTime (LocalTime(..), TimeOfDay(..), TimeZone(..), ZonedTime(..))
 import qualified Data.Tree as Tree
+#if __GLASGOW_HASKELL__ >= 707
+import           Data.Typeable hiding (Proxy)
+#else
 import           Data.Typeable
+#endif
 import           Data.Word
 import           System.Time (ClockTime(..), TimeDiff(..), CalendarTime(..), Month(..))
 import qualified System.Time as OT
@@ -368,8 +372,18 @@ instance SafeCopy CalendarTime where
 typeName :: Typeable a => Proxy a -> String
 typeName proxy = show (typeOf (undefined `asProxyType` proxy))
 
+#if __GLASGOW_HASKELL__ < 707
 typeName1 :: (Typeable1 c) => Proxy (c a) -> String
 typeName1 proxy = show (typeOf1 (undefined `asProxyType` proxy))
 
 typeName2 :: (Typeable2 c) => Proxy (c a b) -> String
 typeName2 proxy = show (typeOf2 (undefined `asProxyType` proxy))
+
+#else
+typeName1 :: (Typeable c) => Proxy (c a) -> String
+typeName1 proxy = show (typeOf1 (undefined `asProxyType` proxy))
+
+typeName2 :: (Typeable c) => Proxy (c a b) -> String
+typeName2 proxy = show (typeOf2 (undefined `asProxyType` proxy))
+#endif
+
